@@ -22,23 +22,23 @@ import os
 # For testing
 import __builtin__
 if not hasattr(__builtin__, '_'):
-	def _(string):
-		return string
+    def _(string):
+        return string
 
-version = 			'1.0.0'
-author = 			'Jendrik Seipp'
-authorMail = 		'jendrikseipp@web.de'
-url = 				'http://rednotebook.sourceforge.net'
-forum_url = 		'http://apps.sourceforge.net/phpbb/rednotebook/'
-translation_url = 	'https://translations.launchpad.net/rednotebook/'
-bug_url = 			'https://bugs.launchpad.net/rednotebook/+filebug'
+version =           '1.1.1'
+author =            'Jendrik Seipp'
+authorMail =        'jendrikseipp@web.de'
+url =               'http://rednotebook.sourceforge.net'
+forum_url =         'http://apps.sourceforge.net/phpbb/rednotebook/'
+translation_url =   'https://translations.launchpad.net/rednotebook/'
+bug_url =           'https://bugs.launchpad.net/rednotebook/+filebug'
 
-developers = 	['Jendrik Seipp <jendrikseipp@web.de>',
-				'',
-				'Contributors:',
-				'Alexandre Cucumel <superkiouk@gmail.com>',
-				]
-				
+developers =    ['Jendrik Seipp <jendrikseipp@web.de>',
+                '',
+                'Contributors:',
+                'Alexandre Cucumel <superkiouk@gmail.com>',
+                ]
+                
 comments = '''\
 RedNotebook is a graphical journal to keep track of notes and \
 thoughts. It includes a calendar navigation, customizable \
@@ -46,8 +46,8 @@ templates, export functionality and word clouds. You can also \
 format, tag and search your entries.\
 '''
 
-licenseText = '''\
-Copyright (c) 2009  Jendrik Seipp
+license_text = '''\
+Copyright (c) 2009,2010  Jendrik Seipp
 
 RedNotebook is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -262,7 +262,7 @@ Once you've finished an item, you could also change its category name from \
 "Todo" to "Done".''',
 u'Tags': {u'Documentation': None,},
 u'Todo': {u'--Remember the milk--': None,
-		u'Take a break': None},
+        u'Take a break': None},
 u'Done': {u'--Check mail--': None,},
 }
 
@@ -277,13 +277,13 @@ multiple_entries_text = multiple_entries_text.replace('=== Play ===', '**Play**\
 todo_help_text = example_day3['text']
 
 
-helpText = '''
-== Text ==
+help_text = '''
+==== Text ====
 The main text field is the container for your normal diary entries like this one:
 
 %(example_entry)s
 
-== Format ==
+==== Format ====
 As you see, the text can be formatted **bold**, \
 //italic//, --struck through-- and __underlined__. As a convenience there \
 is also the "Format" button, with which you can format the main text and nodes \
@@ -302,7 +302,7 @@ this text was formatted by looking at its [source source.txt].
 
 %(ann_help_text)s
 
-== Images, Files and Links ==
+==== Images, Files and Links ====
 RedNotebook lets you insert images, files and links into your entries. \
 To do so, select the appropriate option in the "Insert" pull-down menu \
 above the main text field. The text will be inserted at the current \
@@ -311,14 +311,14 @@ cursor position.
 With the insert button you cannot insert **links to directories** on your computer. \
 Those can be inserted manually however (""[Home ""file:///home/""]"").
 
-== %(templates)s ==
+==== %(templates)s ====
 %(temp_par)s 
 The files 1.txt to 7.txt in the template directory correspond to the templates \
 for each day of the week. The current weekday's template will be filled \
 into the text area when you click on "Template". You can open the template files \
 from inside RedNotebook by opening the menu next to the "Template" button.
 
-== Tags ==
+==== Tags ====
 Tagging an entry (e.g. with the tag "Work") is also easy: \
 On the right, click on "Add Tag" and insert \
 "Work" into the lower textbox. The result looks like:
@@ -331,18 +331,18 @@ You can see a tag cloud on the left by activating the "Clouds" tab and \
 selecting "Tags". Get a list of all tags with a given name by clicking \
 on that tag in the cloud.
 
-== Search ==
+==== Search ====
 On the left you find the search box. You can search for text, display a \
 category's content or show all days with a given tag. \
 Double-clicking on a day lets you jump to it.
 
-== Clouds ==
+==== Clouds ====
 Clicking on the "Clouds" tab on the left lets you view the most often used words in your journal.
 You can select to view your category or tag clouds by clicking on the scroll-down menu.
 If words appear in the cloud that you don't want to see there, just right-click on them. \
 Alternatively you can open the Preferences dialog and add the words to the cloud blacklist there.
 
-== Spellcheck ==
+==== Spellcheck ====
 RedNotebook supports spellchecking your entries if you have \
 python-gtkspell installed (Only available on Linux). \
 To highlight all misspelled words in your entries, select the corresponding option in \
@@ -351,14 +351,30 @@ the preferences window.
 Since gtkspell 2.0.15, you can select the spellchecking language by right-clicking on the \
 main text area (in edit mode) and choosing it from the submenu "Languages".
 
-== Options ==
+==== Options ====
 Make sure you check out the customizable options in the Preferences dialog. You can
 open this dialog by clicking on the entry in the "Edit" menu.
 
-== Save ==
+==== Save ====
 %(save1)s %(save2)s %(save3)s
 
-== Synchronize across multiple computers ==[sync]
+==== Export ====
+%(save4)s %(save5)s
+
+Since version 0.9.2 you can also directly export your journal to PDF. If the \
+option does not show up in the export assistant, you need to install \
+pywebkitgtk version 1.1.5 or later (the package is sometime called \
+python-webkit). 
+
+**Latex caveats**
+
+Make sure to type all links with the full path including the protocol:
+
+- http://www.wikipedia.org or http://wikipedia.org (--wikipedia.org--, --"""www.wikipedia.org"""--)
+- file:///home/sam/myfile.txt (--/home/sam/myfile.txt--)
+
+
+==== Synchronize across multiple computers ====[sync]
 Syncing RedNotebook with a remote server is easy. You can either use a \
 cloud service like Ubuntu One or Dropbox or save your journal to your \
 own server.
@@ -401,7 +417,7 @@ the file "rednotebook/files/default.cfg". There you can set the value of \
 userDir to the path where you want to share your settings between the \
 systems.
 
-== Portable mode ==
+==== Portable mode ====
 RedNotebook can be run in portable mode. In this mode, the \
 template directory and the configuration and log file are saved \
 in the application directory instead of in the home directory. \
@@ -416,25 +432,14 @@ portable mode.
 To **activate portable mode**, change into the files/ directory and in the \
 default.cfg file set portable=1.
 
-== Export ==
-%(save4)s %(save5)s
+=== Convert Latex output to PDF ===
 
-**Latex caveats**
-
-Make sure to type all links with the full path including the protocol:
-
-- http://www.wikipedia.org or http://wikipedia.org (--wikipedia.org--, --"""www.wikipedia.org"""--)
-- file:///home/sam/myfile.txt (--/home/sam/myfile.txt--)
-
-
-===Convert Latex output to PDF===
-
-Since version 0.9.2 you can export your journal directly to PDF on Linux, \
+In recent RedNotebook versions you can export your journal directly to PDF, \
 so this section may be obsolete. \
 However, there may be some people who prefer to export their \
 journal to Latex first and convert it to PDF later. Here is how you do it:
 
-**Linux**
+== Linux ==
 
 For the conversion on Linux you need some extra packages: texlive-latex-base and \
 texlive-latex-recommended. Maybe you also need texlive-latex-extra. Those contain \
@@ -457,7 +462,7 @@ If you run into any problems during the conversion, the easiest way to solve \
 them is to install a latex editor and do the conversion with it. That way \
 you can see the errors right away and get rid of them by editing the file.
 
-**Windows**
+== Windows ==
 
 You can open an exported Latex file with Texniccenter and convert it to PDF \
 with MikTex. Visit www.texniccenter.org/ and www.miktex.org \
@@ -466,7 +471,7 @@ open the .tex file with Texniccenter and select "Build Output" from the \
 "Output" menu. The program will then create the beautifully looking PDF in the
 same directory.
 
-== Keyboard Shortcuts ==
+==== Keyboard Shortcuts ====
 ||   Action          |   Shortcut             |
 | Preview (On/Off)   | <Ctrl> + P             |
 | Find               | <Ctrl> + F             |
@@ -479,7 +484,7 @@ same directory.
 
 You can find other shortcuts in the menus.
 
-== Encryption ==
+==== Encryption ====
 You can use e.g. [TrueCrypt http://www.truecrypt.org] to encrypt your \
 journal. Nick Bair has written a nice tutorial about \
 [encrypting RedNotebook files \
@@ -495,7 +500,7 @@ This method is especially useful for laptop users, because their \
 computers are more likely to be stolen. If you encrypt your home \
 partition all RedNotebook data will be encrypted, too.
 
-== Tips ==
+==== Tips ====
 %(multiple_entries_text)s
 
 %(todo_help_text)s
@@ -564,7 +569,7 @@ To get a list of all entries, just search for " " (the space character). \
 This character is most likely included in all entries. You can sort the \
 resulting list chronologically by pressing the "Date" button.
 
-== Command line options ==
+==== Command line options ====
 ```
 Usage: rednotebook [options] [journal-path]
 
@@ -580,14 +585,14 @@ At the first program start this defaults to "$HOME/.rednotebook/data".
 
 
 Options:
-  -h, --help     	show this help message and exit
+  -h, --help        show this help message and exit
 
-  -d, --debug    	Output debugging messages (default: False)
+  -d, --debug       Output debugging messages (default: False)
 
-  -m, --minimized	Start mimimized to system tray (default: False)
+  -m, --minimized   Start mimimized to system tray (default: False)
 ```
 
-== Data Format ==
+==== Data Format ====
 In this paragraph I will explain shortly what the RedNotebook files \
 consist of. Firstly it is important to understand that the content \
 is saved in a directory with many files, not just one file. \
@@ -616,12 +621,12 @@ the main content area. Additionally there can be multiple other keys \
 that stand for the categories that belong to that day. Each category \
 contains a dictionary with only one key, the category entry.
 
-== Questions ==
+==== Questions ====
 If you have any questions or comments, feel free to post them in the \
 [forum http://apps.sourceforge.net/phpbb/rednotebook/] or \
 contact me directly.
 
-== Bugs ==
+==== Bugs ====
 There is no software without bugs, so if you encounter one please drop me a note.
 This way RedNotebook can get better not only for you, but for all users.
 
@@ -644,30 +649,30 @@ StartupNotify=true
 '''
 
 def write_documentation(dir):
-	'''
-	Write the documenation as html to a directory
-	Include the original markup as "source.txt"
-	'''
-	from rednotebook.util import utils
-	from rednotebook.util import markup
+    '''
+    Write the documenation as html to a directory
+    Include the original markup as "source.txt"
+    '''
+    from rednotebook.util import utils
+    from rednotebook.util import markup
 
-	utils.write_file(helpText, os.path.join(dir, 'source.txt'))
-	headers = [_('RedNotebook Documentation'), version, '']
-	options = {'toc': 1,}
-	html = markup.convert(helpText, 'xhtml', headers, options)
-	utils.write_file(html, os.path.join(dir, 'help.html'))
+    utils.write_file(help_text, os.path.join(dir, 'source.txt'))
+    headers = [_('RedNotebook Documentation'), version, '']
+    options = {'toc': 1,}
+    html = markup.convert(help_text, 'xhtml', headers, options)
+    utils.write_file(html, os.path.join(dir, 'help.html'))
 
 if __name__ == '__main__':
-	import sys
-	sys.path.insert(0, os.path.abspath("./../"))
+    import sys
+    sys.path.insert(0, os.path.abspath("./../"))
 
-	print completeWelcomeText
-	print '*'*80
-	print helpText
+    print completeWelcomeText
+    print '*'*80
+    print helpText
 
-	doc_dir = '../doc'
-	doc_dir = os.path.abspath(doc_dir)
+    doc_dir = '../doc'
+    doc_dir = os.path.abspath(doc_dir)
 
-	write_documentation(doc_dir)
+    write_documentation(doc_dir)
 
-	#logging.getLogger('').setLevel(logging.DEBUG)
+    #logging.getLogger('').setLevel(logging.DEBUG)
