@@ -21,9 +21,9 @@ from __future__ import with_statement
 
 import os
 import sys
-import mimetypes
 import logging
 import time
+import codecs
 
 import gtk
 
@@ -46,7 +46,7 @@ Your text can be:
 - **bold**
 - //italic//
 - __underlined__
-- --stricken--
+- --strikethrough--
 
 
 You can add images to your template:
@@ -79,10 +79,10 @@ the current date. You can set the date format in the preferences.
 
 
 class TemplateManager(object):
-	def __init__(self, mainWindow):
-		self.mainWindow = mainWindow
+	def __init__(self, main_window):
+		self.main_window = main_window
 		
-		self.dirs = mainWindow.redNotebook.dirs
+		self.dirs = main_window.journal.dirs
 		
 		self.merge_id = None
 		self.actiongroup = None
@@ -98,7 +98,7 @@ class TemplateManager(object):
 			text = self.get_weekday_text()
 		else:
 			text = self.get_text(title)
-		self.mainWindow.dayTextField.insert(text)
+		self.main_window.day_text_field.insert(text)
 		
 		
 	def on_edit(self, action):
@@ -109,9 +109,9 @@ class TemplateManager(object):
 		title = edit_title[4:]
 		
 		if title == 'Weekday':
-			date = self.mainWindow.redNotebook.date
-			weekDayNumber = date.weekday() + 1
-			title = str(weekDayNumber)
+			date = self.main_window.journal.date
+			week_day_number = date.weekday() + 1
+			title = str(week_day_number)
 		
 		filename = self.titles_to_files.get(title)
 		filesystem.open_url(filename)
@@ -132,65 +132,57 @@ class TemplateManager(object):
 			title = entry.get_text()
 			if not title.lower().endswith('.txt'):
 				title += '.txt'
-			filename = os.path.join(self.dirs.templateDir, title)
+			filename = os.path.join(self.dirs.template_dir, title)
 			
-			filesystem.makeFile(filename, example_text)
+			filesystem.make_file(filename, example_text)
 			
 			filesystem.open_url(filename)
 			
 	
 	def on_open_template_dir(self):
-		filesystem.open_url(self.dirs.templateDir)
+		filesystem.open_url(self.dirs.template_dir)
 		
 	
-	def getTemplateFile(self, basename):
-		return os.path.join(self.dirs.templateDir, str(basename) + '.txt')
+	def get_template_file(self, basename):
+		return os.path.join(self.dirs.template_dir, str(basename) + '.txt')
 		
 		
 	def get_text(self, title):
 		filename = self.titles_to_files.get(title, None)
 		if not filename:
 			return ''
-		
-		try:
-			with open(filename, 'r') as templateFile:
-				text = templateFile.read()
-		except IOError, Error:
-			logging.error('Template File %s not found' % filename)
-			text = ''
 			
-		try:
-			#logging.debug('Read template content: "%s"', text)
-			# Only reading utf-8 files is supported
-			text = text.decode('utf-8', 'ignore')
-		except UnicodeDecodeError, UnicodeEncodeError:
-			logging.error('Template file contains unreadable content. Is it really just ' \
-						'a text file?')
-			text = ''
-			
-		# convert every "$date$" to the current date
-		default_date_string = '%A, %x %X'
-		date_string = self.mainWindow.redNotebook.config.read('dateTimeString', default_date_string)
-		date = time.strftime(date_string)
-		text = text.replace('$date$', date)
+		text = filesystem.read_file(filename)
 		
+		# An Error occured
 		if not text:
 			text = 'This template contains no text or has unreadable content. To edit it, ' \
 					'click the arrow right of "Template" ' \
-					'and select the template under "Edit Template".'
+					'and select the template under "Edit Template".'		
+			
+		# convert every "$date$" to the current date
+		default_date_string = '%A, %x %X'
+		date_string = self.main_window.journal.config.read('dateTimeString', default_date_string)
+		date = time.strftime(date_string)
+		try:
+			text = text.replace('$date$', date)
+		except UnicodeDecodeError, err:
+			# TODO: Figure out real source of the error,
+			# maybe load config with filesystem.read_file
+			logging.error('Error replacing $date$: "%s"' % err)
 		
 		return text
 		
 		
 	def get_weekday_text(self, date=None):
 		if date is None:
-			date = self.mainWindow.redNotebook.date
-		weekDayNumber = date.weekday() + 1
-		return self.get_text(str(weekDayNumber))
+			date = self.main_window.journal.date
+		week_day_number = date.weekday() + 1
+		return self.get_text(str(week_day_number))
 		
 	
 	def get_available_template_files(self):
-		dir = self.dirs.templateDir
+		dir = self.dirs.template_dir
 		files = os.listdir(dir)
 		files = map(lambda basename: os.path.join(dir, basename), files)
 		
@@ -268,7 +260,7 @@ class TemplateManager(object):
 		</popup>
 		</ui>'''
 			
-		uimanager = self.mainWindow.uimanager
+		uimanager = self.main_window.uimanager
 		
 		if self.actiongroup:
 			uimanager.remove_action_group(self.actiongroup)
@@ -329,8 +321,8 @@ class TemplateManager(object):
 		
 	
 	def make_empty_template_files(self):
-		def getInstruction(dayNumber):
-			file = self.getTemplateFile(dayNumber)
+		def get_instruction(day_number):
+			file = self.get_template_file(day_number)
 			#text = '''\
 #The template for this weekday has not been edited. 
 #If you want to have some text that you can add to that day every week, \
@@ -341,9 +333,9 @@ class TemplateManager(object):
 			text = example_text
 			return text
 					
-		fileContentPairs = []
-		for dayNumber in range(1, 8):
-			fileContentPairs.append((self.getTemplateFile(dayNumber), getInstruction(dayNumber)))
+		file_content_pairs = []
+		for day_number in range(1, 8):
+			file_content_pairs.append((self.get_template_file(day_number), get_instruction(day_number)))
 		
 		template_help_text = '''\
 Besides templates for weekdays you can also have arbitrary named templates. 
@@ -361,15 +353,15 @@ You can switch to "Preview" mode and click on the link to get to the \
 If you come up with templates that could be useful for other people as well, \
 I would appreciate if you sent me your template file, so others can benefit \
 from it.
-		''' % (self.dirs.templateDir, self.dirs.templateDir)
+		''' % (self.dirs.template_dir, self.dirs.template_dir)
 		
-		template_help_filename = self.getTemplateFile('Help')
-		fileContentPairs.append((template_help_filename, template_help_text))
+		template_help_filename = self.get_template_file('Help')
+		file_content_pairs.append((template_help_filename, template_help_text))
 		
 		# Only add the example templates the first time and just restore
 		# the day templates everytime
-		if not self.mainWindow.redNotebook.firstTimeExecution:
-			filesystem.makeFiles(fileContentPairs)
+		if not self.main_window.journal.dirs.is_first_start:
+			filesystem.make_files(file_content_pairs)
 			return
 		
 		
@@ -408,8 +400,8 @@ Additional items: Xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx. Xxxxxxxxxxxxxxxxxxxxx
  - Xxxxxxxxxx Xxxxxxxxxxxx
 		'''
 		
-		template_meeting_filename = self.getTemplateFile('Meeting')
-		fileContentPairs.append((template_meeting_filename, template_meeting_text))
+		template_meeting_filename = self.get_template_file('Meeting')
+		file_content_pairs.append((template_meeting_filename, template_meeting_text))
 		
 		
 		template_journey_text = '''\
@@ -426,8 +418,8 @@ First we went to xxxxx then we got to yyyyy ...
 **Pictures:** [Image folder ""/path/to/the/images/""]
 		'''
 		
-		template_journey_filename = self.getTemplateFile('Journey')
-		fileContentPairs.append((template_journey_filename, template_journey_text))
+		template_journey_filename = self.get_template_file('Journey')
+		file_content_pairs.append((template_journey_filename, template_journey_text))
 		
 		
-		filesystem.makeFiles(fileContentPairs)
+		filesystem.make_files(file_content_pairs)
