@@ -20,16 +20,16 @@
 import datetime
 
 
-oneDay = datetime.timedelta(days=1)
+one_day = datetime.timedelta(days=1)
 		
-def getYearAndMonthFromDate(date):
-	yearAndMonth = date.strftime('%Y-%m')
-	assert len(yearAndMonth) == 7
-	return yearAndMonth
+def get_year_and_month_from_date(date):
+	year_and_month = date.strftime('%Y-%m')
+	assert len(year_and_month) == 7
+	return year_and_month
 
-def get_date_from_date_string(dateString):
-	dateArray = dateString.split('-')
-	year, month, day = map(int, dateArray)
+def get_date_from_date_string(date_string):
+	date_array = date_string.split('-')
+	year, month, day = map(int, date_array)
 	return datetime.date(year, month, day)
 
 # Number of days per month (except for February in leap years)
@@ -40,6 +40,9 @@ def isleap(year):
 	return year % 4 == 0 and (year % 100 != 0 or year % 400 == 0)
 
 def get_number_of_days(year, month):
+	'''
+	Return the number of days in a given month of a given year
+	'''
 	days = month_days[month] + (month == 2 and isleap(year))
 	return days
 
